package com.example.projectapplication;

import androidx.annotation.RequiresApi;
import androidx.appcompat.app.AppCompatActivity;

import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.icu.util.Calendar;
import android.os.Build;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.*;

import java.sql.Date;
import java.util.ArrayList;
import java.util.HashMap;

import utility.SSpost;

import static com.example.projectapplication.LoginActivity.userID;

public class AddActivity extends AppCompatActivity {
    // 组件
    private TextView editText_date;
    private ImageButton imageButton_Cal;
    private Button btn_addConfirm;
    private Button btn_addMeal;
    private RadioGroup radioGroup_time;
    private RadioButton radioButton;

    // 变量
    private Date date;
    private String type = "breakfast";
    private String meal;
    private Double quantity;
    private String unit;

    // ListView 组件
    private ListView entryList;   // ListView 控件
    private ArrayList<HashMap<String, Object>> listItem;  // ListView的数据源，这里是一个HashMap的列表
    private MyAdapter listItemAdapter;  // ListView 适配器

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        // 初始化图像
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_add);

        // 根据ID找到组件
        editText_date = (TextView) findViewById(R.id.editText_date);
        imageButton_Cal = (ImageButton) findViewById(R.id.imageButton_Cal);
        btn_addConfirm = (Button) findViewById(R.id.btn_addConfirm);
        btn_addMeal = (Button) findViewById(R.id.btn_addMeal);
        radioGroup_time = (RadioGroup) findViewById(R.id.radioGroup_time);

        // 设置按钮监听
        btn_addMeal.setOnClickListener(new AddActivity.MyButton());
        btn_addConfirm.setOnClickListener(new AddActivity.MyButton());
        imageButton_Cal.setOnClickListener(new AddActivity.MyButton());
        // 单选框监听
        radioGroup_time.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
           @Override
           public void onCheckedChanged(RadioGroup group, int checkedId) {
               selectRadioBtn();
           }
        });


        // 初始化 ListView 变量
        listItem = new ArrayList<HashMap<String, Object>>();
        listItemAdapter = new MyAdapter(this);
        entryList = (ListView)findViewById(R.id.ListView_add);
        entryList.setAdapter(listItemAdapter);

        // 设置预设日期
        date = new Date(System.currentTimeMillis());
        editText_date.setText(date.toString().substring(0, 10));
    }

// 下面这个重载 是为了让 singleTask 活动能够正确接收 intent 的传值
    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        setIntent(intent);
        //here we can use getIntent() to get the extra data.
    }

// activity 恢复时刷新 ListView
    protected void onResume() {
        super.onResume();

        // 处理由 InputActivity传过来的值
        Intent i=getIntent();//因为AddActivity是通过intend来启动的，所以通过getIntend来获取与这个Activity相关的数据
        meal = i.getStringExtra("meal");
        quantity = i.getDoubleExtra("quantity", 0);   //因为InputActivity里通过putExtra传递时名字是quantity
        unit = i.getStringExtra("unit");
        if (meal != null && quantity > 0){
            addItem(meal, quantity, unit);}
    }

// 监听 RadioButton 的修改
    private void selectRadioBtn(){
        radioButton = (RadioButton)findViewById(radioGroup_time.getCheckedRadioButtonId());
        type = radioButton.getText().toString();
        System.out.println(type);
    }

// 添加 Item 方法
    public void addItem(String s, double d, String u) {
        HashMap<String, Object> map = new HashMap<String, Object>();
        meal = s;
        quantity = d;
        unit = u;
        map.put("meal", meal);
        map.put("quantity", quantity);
        map.put("unit", unit);
        listItem.add(map);
        listItemAdapter.notifyDataSetChanged();
    }

    public class MyButton implements View.OnClickListener {
        @RequiresApi(api = Build.VERSION_CODES.N)
        @Override
        public void onClick(View view) {
            if (view.getId() == R.id.btn_addMeal) {
                    // 启动InputActivity
                    Intent intent = new Intent(AddActivity.this, InputActivity.class);
                    startActivity(intent);
            }
            if (view.getId() == R.id.btn_addConfirm) {
              // 遍历储存的 HashMap, 发送条目至数据库
                        for (int i=0;i<listItem.size(); i++){
                            System.out.println(i);
                            meal = listItem.get(i).get("meal").toString();
                            quantity = Double.valueOf(listItem.get(i).get("quantity").toString());
                            unit = listItem.get(i).get("unit").toString();
                            System.out.println(listItem.get(i));
                            SSpost post = new SSpost();
                            post.sendRecord(userID,date,type,meal,quantity,unit);
                        }
                Toast.makeText(AddActivity.this, "Sending data", Toast.LENGTH_SHORT).show();
                Intent intent = new Intent(AddActivity.this, MainActivity.class);
                startActivity(intent);
            }
            if (view.getId() == R.id.imageButton_Cal) {
                Calendar calendar = Calendar.getInstance();
                new DatePickerDialog( AddActivity.this, new DatePickerDialog.OnDateSetListener() {
                    @Override
                    public void onDateSet(DatePicker view, int year, int month, int dayOfMonth) {
                        String text = "You have set the date to" + year + "-" + (month + 1) + "-" + dayOfMonth;
                        date = new Date(year-1900,month,dayOfMonth);
                        editText_date.setText(date.toString());

                        Toast.makeText( AddActivity.this, text, Toast.LENGTH_SHORT ).show();
                    }
                }
                        ,calendar.get(Calendar.YEAR)
                        ,calendar.get(Calendar.MONTH)
                        ,calendar.get(Calendar.DAY_OF_MONTH)).show();
            }
        }
    }

// 定义接下来 BaseAdapter 要用到的 ViewHolder 类
    public final class ViewHolder {
        public TextView meal;
        public TextView quantity;
        public ImageButton imgBtn;
    }

// 自定义一个 BaseAdapter 用以实现点击按钮删除
    public class MyAdapter extends BaseAdapter {

        private LayoutInflater mInflater;

        public MyAdapter(Context context) {
            this.mInflater = LayoutInflater.from(context);
        }

        @Override
        public int getCount() {
            return listItem.size();
        }

        @Override
        public Object getItem(int arg0) {
            return null;
        }

        @Override
        public long getItemId(int arg0) {
            return 0;
        }

        /**
         * listView在开始绘制的时候，系统首先调用getCount（）函数，根据他的返回值得到listView的长度
         * 然后根据这个长度，调用getView（）逐一绘制每一行。 如果你的getCount（）返回值是0的话，列表将不显示同样return
         * 1，就只显示一行。 　系统显示列表时，首先实例化一个适配器。
         *
         * 当手动完成适配时，必须手动映射数据，这需要重写getView（）方法。 系统在绘制列表的每一行的时候都将调用此方法，（可以设个变量试试）
         * getView()有三个参数 position表示将显示的是第几行 covertView是从布局文件中inflate来的布局
         * 我们用LayoutInflater的方法将定义好的vlist2.xml文件提取成View实例用来显示。
         * 然后将xml文件中的各个组件实例化（简单的findViewById()方法）。 这样便可以将数据对应到各个组件上了
         *
         * 但是按钮为了响应点击事件，需要为它添加点击监听器，这样就能捕获点击事件。 至此一个自定义的listView就完成了
         *
         * 现在让我们回过头从新审视这个过程 系统要绘制ListView了，他首先获得要绘制的这个列表的长度，然后开始绘制第一行，怎么绘制呢？
         * 调用getView()函数。在这个函数里面首先获得一个View（实际上是一个ViewGroup） 然后再实例并设置各个组件并显示。
         * 绘制完这一行了。再绘制下一行，直到绘完为止。
         */
        @Override
        public View getView(final int position, View convertView,
                            ViewGroup parent) {

            // 通过Log.i()可以发现这个会多次调用，容易理解

            ViewHolder holder = null;
            if (convertView == null) {

                holder = new ViewHolder();

                convertView = mInflater.inflate(R.layout.fragment_input_entry, null);
                holder.meal = (TextView) convertView
                        .findViewById(R.id.textView_type);
                holder.quantity = (TextView) convertView
                        .findViewById(R.id.textView_quantity);
                holder.imgBtn = (ImageButton) convertView
                        .findViewById(R.id.imgbtn_del);
                convertView.setTag(holder);

            } else {

                holder = (ViewHolder) convertView.getTag();
            }

            // holder.img.setBackgroundResource((Integer) mData.get(position).get("img"));
            holder.meal.setText((String) listItem.get(position).get("meal"));
            holder.quantity.setText((String) listItem.get(position).get("quantity").toString());
            holder.imgBtn.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    showInfo(position);
                }
            });
            return convertView;
        }
    }

    // ListView中点击按键弹出对话框
    public void showInfo(final int position) {
        new AlertDialog.Builder(this).setTitle("Message").setMessage("Delete this entry？")
                .setPositiveButton("Yes", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        listItem.remove(position);
                        // 通过程序我们知道删除了，但是怎么刷新ListView呢？
                        // 只需要重新设置一下adapter
                        entryList.setAdapter(listItemAdapter);
                    }
                }).show();
    }

}