package com.example.projectapplication.ui.notifications;

import android.app.ProgressDialog;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.SimpleAdapter;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;

import com.android.volley.DefaultRetryPolicy;
import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.RetryPolicy;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.example.projectapplication.R;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;

import static com.example.projectapplication.LoginActivity.group;
import static com.example.projectapplication.LoginActivity.userID;

public class NotificationsFragment extends Fragment {

    //变量
    private String from;
    private String to ;
    private String message;

    // ListView 组件
    private ListView notificationList;   // ListView 控件
    private ArrayList<HashMap<String, Object>> listItem;  // ListView的数据源，这里是一个HashMap的列表
    private SimpleAdapter listItemAdapter;  // ListView 适配器

    // 组件
    ProgressDialog loading;

    // onCreateView 方法
    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_notification_page, null);

        // 初始化 ListView 变量
        listItem = new ArrayList<HashMap<String, Object>>();
        listItemAdapter = new SimpleAdapter(
                this.getContext(),
                listItem,
                R.layout.fragment_notification_entry,
                new String[]{"from","to","message"},
                new int[]{R.id.textView_from, R.id.textView_to, R.id.textView_message}
        );
        notificationList = (ListView) view.findViewById(R.id.listView_notification);
        notificationList.setAdapter(listItemAdapter);

        // 显示数据
        getItems();

        return view;
    }

    private void getItems() {

        loading = ProgressDialog.show(this.getContext(), "Loading", "please wait", false, true);
        StringRequest stringRequest = new StringRequest(Request.Method.GET, "https://script.google.com/macros/s/AKfycbxAZAp0aEZgk7cZBEQBOyzJzK_8FX47cB4IC27Q9GgDnoQMWCs/exec",
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        System.out.println(response);
                        parseItems(response);
                    }
                },

                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {
                    }
                }
        );

        int socketTimeOut = 50000;
        RetryPolicy policy = new DefaultRetryPolicy(socketTimeOut, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT);

        stringRequest.setRetryPolicy(policy);

        RequestQueue queue = Volley.newRequestQueue(this.getContext());
        queue.add(stringRequest);
    }


    private void parseItems(String jsonResponse) {

        try {
            JSONObject jobj = new JSONObject(jsonResponse);
            JSONArray jarray = jobj.getJSONArray("items");

            for (int i = 0; i < jarray.length(); i++) {

                JSONObject jo = jarray.getJSONObject(i);

                to =  jo.getString("To");
                from = jo.getString("From");
                message = jo.getString("Message");

                if (to.equals(userID) ||  to.equals(group) || to.equals("All")) {
                    HashMap<String, Object> item = new HashMap<>();
                    item.put("from", "From: " + from);
                    item.put("to", "To: " + to);
                    item.put("message", message);

                    listItem.add(item);
                }
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }

        listItemAdapter.notifyDataSetChanged();
        loading.dismiss();
    }
}