package utility;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseExpandableListAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.example.projectapplication.R;

import java.util.ArrayList;
import java.util.HashMap;

/**
 * Created by fyf on 2019/3/1.
 * 描述：是二级显示列表的adapter
 */
public class ExpandableAdapter extends BaseExpandableListAdapter {
    //Model：定义的数据
    private ArrayList<String> groups;
    //注意，字符数组不要写成{{"A1,A2,A3,A4"}, {"B1,B2,B3,B4，B5"}, {"C1,C2,C3,C4"}}
    private ArrayList<ArrayList<HashMap<String, Object>>> children;
    private Context context;

    public ExpandableAdapter(Context context, ArrayList<String> groups, ArrayList<ArrayList<HashMap<String, Object>>> children) {
        this.context = context;
        this.groups = groups;
        this.children = children;
    }

    @Override
    public int getGroupCount() {
        if (groups != null){
            return groups.size();
        }
        else{
            return 0;
        }
    }

    @Override
    public int getChildrenCount(int i) {
        try {
            return children.get(i).size();
        }
        catch (Exception e) {
            return 0;
        }
    }

    @Override
    public Object getGroup(int i) {
        return groups.get(i);
    }

    @Override
    public Object getChild(int i, int i1) {
        return children.get(i).get(i1);
    }

    @Override
    public long getGroupId(int i) {
        return i;
    }

    @Override
    public long getChildId(int i, int i1) {
        return i1;
    }

    @Override
    //分组和子选项是否持有稳定的ID, 就是说底层数据的改变会不会影响到它们
    public boolean hasStableIds() {
        return true;
    }

    @Override
/**
 *
 * 获取显示指定组的视图对象
 *
 * groupPosition 组位置
 * @param isExpanded 该组是展开状态还是伸缩状态，true=展开
 * @param convertView 重用已有的视图对象
 * @param parent 返回的视图对象始终依附于的视图组
 */
    public View getGroupView(int groupPosition, boolean isExpanded, View convertView, ViewGroup parent) {
        GroupViewHolder groupViewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(parent.getContext()).inflate(R.layout.fragment_record_parent, parent, false);
            groupViewHolder = new GroupViewHolder();
            groupViewHolder.parent_textview_id = convertView.findViewById(R.id.textView_date);
            groupViewHolder.parent_image = convertView.findViewById(R.id.image_parent);
            convertView.setTag(groupViewHolder);
        } else {
            groupViewHolder = (GroupViewHolder) convertView.getTag();
        }
        groupViewHolder.parent_textview_id.setText(groups.get(groupPosition));
        //如果是展开状态，
        if (isExpanded) {
           // groupViewHolder.parent_image.setImageDrawable(ContextCompat.getDrawable(context, R.drawable.arrow_down_float));
        } else {
           // groupViewHolder.parent_image.setImageDrawable(ContextCompat.getDrawable(context, R.drawable.img_arrow_right));
        }
        return convertView;
    }

    @Override
    public View getChildView(int groupPosition, int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
        ChildViewHolder childViewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(parent.getContext()).inflate(R.layout.fragment_record_entry, parent, false);
            childViewHolder = new ChildViewHolder();
            childViewHolder.children_type = (TextView) convertView.findViewById(R.id.textView_type);
            childViewHolder.children_meal = (TextView) convertView.findViewById(R.id.textView_meal);
            childViewHolder.children_quantity = (TextView) convertView.findViewById(R.id.textView_quantity);
            convertView.setTag(childViewHolder);

        } else {
            childViewHolder = (ChildViewHolder) convertView.getTag();
        }
        childViewHolder.children_type.setText(children.get(groupPosition).get(childPosition).get("type").toString());
        childViewHolder.children_meal.setText(children.get(groupPosition).get(childPosition).get("meal").toString());
        childViewHolder.children_quantity.setText(children.get(groupPosition).get(childPosition).get("quantity").toString());
        return convertView;
    }

    //指定位置上的子元素是否可选中
    @Override
    public boolean isChildSelectable(int i, int i1) {
        return true;
    }

    static class GroupViewHolder {
        TextView parent_textview_id;
        ImageView parent_image;
    }

    static class ChildViewHolder {
        TextView children_type;
        TextView children_meal;
        TextView children_quantity;


    }
}

